aboutsummaryrefslogtreecommitdiff
path: root/bfd/elf64-x86-64.c
diff options
context:
space:
mode:
authorH.J. Lu <hjl.tools@gmail.com>2024-08-31 04:56:48 -0700
committerH.J. Lu <hjl.tools@gmail.com>2024-08-31 05:07:19 -0700
commit5a655b5291b3f56088409d34e9077e98af63de60 (patch)
treebc80e3227c3d2bf0584083acb119424ec240d27c /bfd/elf64-x86-64.c
parent229ecf80f35c64145678e537daf54358d16107e3 (diff)
downloadgdb-5a655b5291b3f56088409d34e9077e98af63de60.zip
gdb-5a655b5291b3f56088409d34e9077e98af63de60.tar.gz
gdb-5a655b5291b3f56088409d34e9077e98af63de60.tar.bz2
x86: Fix comment typos in TLS relocation check
R_386_TLS_IE is used only in movl foo@indntpoff, %eax movl foo@indntpoff, %reg addl foo@indntpoff, %reg R_386_TLS_DESC_CALL and R_X86_64_TLSDESC_CALL are used only in call *x@tlscall(%[er]ax) * elf32-i386.c (elf_i386_check_tls_transition): Use foo@indntpoff in comments for R_386_TLS_IE check. (elf_i386_tls_transition): Use @tlscall in comments for R_386_TLS_DESC_CALL check. * elf64-x86-64.c (elf_x86_64_tls_transition): Use @tlscall in comments for R_X86_64_TLSDESC_CALL check. Signed-off-by: H.J. Lu <hjl.tools@gmail.com>
Diffstat (limited to 'bfd/elf64-x86-64.c')
-rw-r--r--bfd/elf64-x86-64.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/bfd/elf64-x86-64.c b/bfd/elf64-x86-64.c
index cef5cbb..4330bbd 100644
--- a/bfd/elf64-x86-64.c
+++ b/bfd/elf64-x86-64.c
@@ -1448,8 +1448,8 @@ elf_x86_64_tls_transition (struct bfd_link_info *info, bfd *abfd,
{
case R_X86_64_TLSDESC_CALL:
/* Check valid GDesc call:
- call *x@tlsdesc(%rax) <--- LP64 mode.
- call *x@tlsdesc(%eax) <--- X32 mode.
+ call *x@tlscall(%rax) <--- LP64 mode.
+ call *x@tlscall(%eax) <--- X32 mode.
*/
offset = rel->r_offset;
call = NULL;
@@ -1460,7 +1460,7 @@ elf_x86_64_tls_transition (struct bfd_link_info *info, bfd *abfd,
prefix = 0;
if (!ABI_64_P (abfd))
{
/* Check for call *x@tlsdesc(%eax). */
if (call[0] == 0x67)
{
prefix = 1;
@@ -1469,7 +1469,7 @@ elf_x86_64_tls_transition (struct bfd_link_info *info, bfd *abfd,
}
}
/* Make sure that it's a call *x@tlsdesc(%rax). */
if (call != NULL
&& (call[prefix] != 0xff || call[1 + prefix] != 0x10))
call = NULL;
@@ -3842,7 +3842,7 @@ elf_x86_64_relocate_section (bfd *output_bfd,
unsigned int prefix = 0;
if (!ABI_64_P (input_bfd))
{
/* Check for call *x@tlsdesc(%eax). */
if (contents[roff] == 0x67)
prefix = 1;
}
@@ -4302,7 +4302,7 @@ elf_x86_64_relocate_section (bfd *output_bfd,
unsigned int prefix = 0;
if (!ABI_64_P (input_bfd))
{
/* Check for call *x@tlsdesc(%eax). */
if (contents[roff] == 0x67)
prefix = 1;
}
@@ -1460,7 +1460,7 @@ elf_x86_64_tls_transition (struct bfd_link_info *info, bfd *abfd,
if (!ABI_64_P (abfd))
{
- /* Check for call *x@tlsdesc(%eax). */
+ /* Check for call *x@tlscall(%eax). */
if (call[0] == 0x67)
{
@@ -1469,7 +1469,7 @@ elf_x86_64_tls_transition (struct bfd_link_info *info, bfd *abfd,
}
}
- /* Make sure that it's a call *x@tlsdesc(%rax). */
+ /* Make sure that it's a call *x@tlscall(%rax). */
if (call != NULL
&& (call[prefix] != 0xff || call[1 + prefix] != 0x10))
@@ -3842,7 +3842,7 @@ elf_x86_64_relocate_section (bfd *output_bfd,
if (!ABI_64_P (input_bfd))
{
- /* Check for call *x@tlsdesc(%eax). */
+ /* Check for call *x@tlscall(%eax). */
if (contents[roff] == 0x67)
prefix = 1;
@@ -4302,7 +4302,7 @@ elf_x86_64_relocate_section (bfd *output_bfd,
if (!ABI_64_P (input_bfd))
{
- /* Check for call *x@tlsdesc(%eax). */
+ /* Check for call *x@tlscall(%eax). */
if (contents[roff] == 0x67)
prefix = 1;